# Machine learning

На тему ML я задал такой промпт двум моделям - Claude и Deepseek:

```plain
> Напиши на русском языке статью на 15-20 тысяч знаков по теме "Обзор архитектуры ML приложений", в которой раскрой следующие темы:
>
> 1. Основные понятия, концепции и принципы ML
> 2. MLOps процессы и практики 
> 3. Архитектура диалоговых систем
> 4. RAG Retrieval-Augmented Generation
> 5. Распознавание намерений
> Цель: изложить общие понятия, концепции, подходы и принципы полностью, но без воды.
> Аудитория: архитекторы и ведущие программисты с компетенциями по ИТ и разработке, но без знаний в области ML.
```

Результаты получились разные, результаты получились полезные,
но почему-то в обоих случаях не на столько внятные, как при
разговоре о big data.
